==> kadu_0.10.1.orig.tar.bz2: kadu-0.10.1/plugins/encryption_ng/translations/encryption_ng_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Cifratura</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Encrypt by default</source>
        <translation>Cifra di default</translation>
    </message>
    <message>
        <source>Encrypt after receive encrypted message</source>
        <translation>Cifra dopo aver ricevuto il messaggio cifrato</translation>
    </message>
    <message>
        <source>Public key has been sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error during sending public key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption error has occured</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EncryptionActions</name>
    <message>
        <source>Generate Encryption Keys</source>
        <translation>Genera chiavi</translation>
    </message>
    <message>
        <source>Encrypt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send My Public Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Cifratura</translation>
    </message>
    <message>
        <source>Cannot generate keys. Check if encryption_simlite module is loaded</source>
        <translation>Non generare chiavi. Controlla che il modulo encryption_simlite sia caricato</translation>
    </message>
    <message>
        <source>Keys exist. Do you want to overwrite them?</source>
        <translation>Chiavi esistenti. Vuoi sovrascrivere?</translation>
    </message>
    <message>
        <source>Keys have been generated</source>
        <translation>La chiave è stata generata</translation>
    </message>
    <message>
        <source>Error generating keys</source>
        <translation>Errore nella generazione delle chiavi</translation>
    </message>
    <message>
        <source>No public key available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EncryptionNgNotification</name>
    <message>
        <source>Encryption</source>
        <translation>Cifratura</translation>
    </message>
    <message>
        <source>Public key has been send to: %1 (%2)</source>
        <translation>La chiave pubblica è stata inviata a: %1 (%2)</translation>
    </message>
    <message>
        <source>Error sending public key to: %1 (%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error occured during encryption</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EncryptionNgPlugin</name>
    <message>
        <source>Encryption</source>
        <translation type="unfinished">Cifratura</translation>
    </message>
    <message>
        <source>The QCA OSSL plugin for libqca2 is not present!</source>
        <translation type="unfinished">Il plugin QCA OSSL per libqca2 non è presente!</translation>
    </message>
</context>
<context>
    <name>EncryptionProviderManager</name>
    <message>
        <source>Buddy %1 is sending you his public key.
Do you want to save it?</source>
        <translation>Contatto %1 ti sta mandando la sua chiave pubblica. Vuoi salvarla?</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Cifratura</translation>
    </message>
</context>
</TS>

==> kadu_0.11.1.orig.tar.bz2: kadu-0.11.1/plugins/encryption_ng/translations/encryption_ng_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Cifratura</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Encrypt by default</source>
        <translation>Cifra di default</translation>
    </message>
    <message>
        <source>Encrypt after receive encrypted message</source>
        <translation>Cifra dopo aver ricevuto il messaggio cifrato</translation>
    </message>
    <message>
        <source>Public key has been sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error during sending public key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption error has occured</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EnableEncryptionActionDescription</name>
    <message>
        <source>Encrypt</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EncryptionNgNotification</name>
    <message>
        <source>Encryption</source>
        <translation>Cifratura</translation>
    </message>
    <message>
        <source>Public key has been send to: %1 (%2)</source>
        <translation>La chiave pubblica è stata inviata a: %1 (%2)</translation>
    </message>
    <message>
        <source>Error sending public key to: %1 (%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error occured during encryption</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EncryptionNgPlugin</name>
    <message>
        <source>Encryption</source>
        <translation type="unfinished">Cifratura</translation>
    </message>
    <message>
        <source>The QCA OSSL plugin for libqca2 is not present!</source>
        <translation type="unfinished">Il plugin QCA OSSL per libqca2 non è presente!</translation>
    </message>
</context>
<context>
    <name>EncryptionProviderManager</name>
    <message>
        <source>Buddy %1 is sending you his public key.
Do you want to save it?</source>
        <translation>Contatto %1 ti sta mandando la sua chiave pubblica. Vuoi salvarla?</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Cifratura</translation>
    </message>
</context>
<context>
    <name>GenerateKeysActionDescription</name>
    <message>
        <source>Generate Encryption Keys</source>
        <translation>Genera chiavi</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Cifratura</translation>
    </message>
    <message>
        <source>Cannot generate keys. Check if encryption_simlite module is loaded</source>
        <translation>Non generare chiavi. Controlla che il modulo encryption_simlite sia caricato</translation>
    </message>
    <message>
        <source>Keys exist. Do you want to overwrite them?</source>
        <translation>Chiavi esistenti. Vuoi sovrascrivere?</translation>
    </message>
    <message>
        <source>Keys have been generated</source>
        <translation>La chiave è stata generata</translation>
    </message>
    <message>
        <source>Error generating keys</source>
        <translation>Errore nella generazione delle chiavi</translation>
    </message>
</context>
<context>
    <name>SendPublicKeyActionDescription</name>
    <message>
        <source>Send My Public Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No public key available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
